@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import datetime
+import os
 
 from python_search.ranking.next_item_predictor.inference.embeddings_loader import \
     InferenceEmbeddingsLoader
@@ -24,10 +25,14 @@ class InferenceInput:
         Do inference based on the current time and the recent used keys
         """
         now = datetime.datetime.now()
+        hour = int(os.environ["FORCE_HOUR"]) if "FORCE_HOUR" in os.environ else now.hour
+        month = (
+            int(os.environ["FORCE_MONTH"]) if "FORCE_MONTH" in os.environ else now.month
+        )
 
         instance = InferenceInput(
-            hour=now.hour,
-            month=now.month,
+            hour=hour,
+            month=month,
             previous_key=previous_key,
             previous_previous_key=previous_previous_key,
         )
