@@ -45,7 +45,7 @@ class OfflineEvaluation:
                 previous_key=row["previous_key"],
                 previous_previous_key=row["previous_previous_key"],
             )
-            result = inference.get_ranking(predefined_input=input, return_weights=False)
+            result = inference.get_ranking(predefined_input=input, print_weights=False)
 
             metadata = {
                 "pair": row["previous_key"] + " -> " + row["key"],
