@@ -1,19 +1,32 @@
+import json
+import logging
 from datetime import datetime
 
+from colorama import Fore, Style
+
 from python_search.config import ConfigurationLoader
 
 
 class Preview:
-    """ Preview the entry in the search ui """
+    """
+    Preview the entry in the search ui
+    """
+
     def __init__(self):
         self.configuration = ConfigurationLoader()
+        self.logger = logging.getLogger("preview_entry")
+        # do not send the errors to stderr, in the future we should send to kibana or a file
+        self.logger.propagate = False
 
-    def display(self, entry_text):
+    def display(self, entry_text: str):
         """
         Prints the entry in the preview window
         """
-        key = entry_text.split(":")[0]
-        from colorama import Fore, Style
+        data = entry_text.split(":")
+        key = data[0]
+        # the entry content is after the key + a ":" character
+        serialized_content = entry_text[len(key) + 1 :]
+        type = "Unknown"
 
         try:
 
@@ -47,7 +60,6 @@ class Preview:
                 if "cmd" in entry_data:
                     del entry_data["cmd"]
 
-
             if "callable" in entry_data:
                 value = entry_data.get("callable")
                 import dill
@@ -57,11 +69,10 @@ class Preview:
                 if "callable" in entry_data:
                     del entry_data["callable"]
 
-
             print("")
 
-            print(f"Key: {Fore.YELLOW}{key}{Style.RESET_ALL}")
-            print("Type: " + type)
+            print(f"key: {Fore.YELLOW}{key}{Style.RESET_ALL}")
+            print("type: " + type)
 
             for key, value in entry_data.items():
                 print(f"{key}: {value}")
@@ -71,9 +82,15 @@ class Preview:
 
                 creation_date = parser.parse(entry_data["created_at"])
                 today = datetime.now()
-                print(f"Entry age: {today - creation_date}")
+                print(f"entry age: {today - creation_date}")
+
+            try:
+                decoded_content = json.loads(serialized_content)
+                print(f"position: {decoded_content['position']}")
+            except Exception as e:
+                self.logger.error(str(e))
+                pass
 
         except BaseException as e:
-            print(entry_text)
-            print(f"""Error while decoding: {e}""")
-            raise e
+            print(e)
+            self.logger.error(str(e))
